@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: amacro.c,v 1.8 2004/04/04 19:53:44 spetm Exp $
+ * $Id: amacro.c,v 1.14 2008/01/03 00:19:21 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
  * Allocates a new instruction structure
  */
 static instruction_t *
-new_instruction()
+new_instruction(void)
 {
     instruction_t *instruction;
 
@@ -52,7 +52,7 @@ new_instruction()
  * Allocates a new amacro structure
  */
 static amacro_t *
-new_amacro()
+new_amacro(void)
 {
     amacro_t *amacro;
 
@@ -76,9 +76,12 @@ parse_aperture_macro(gerb_file_t *fd)
 {
     amacro_t *amacro;
     instruction_t *ip = NULL;
-    int primitive = 0;
+    int primitive = 0, c, found_primitive = 0;
     enum opcodes math_op = NOP;
-    int comma = 0, neg = 0; /* negative numbers succeding , */
+    int comma = 0; /* Just read an operator (one of '*+X/) */
+    int neg = 0; /* negative numbers succeding , */
+    unsigned char continueLoop = 1;
+    int equate = 0;
 
     amacro = new_amacro();
 
@@ -86,30 +89,33 @@ parse_aperture_macro(gerb_file_t *fd)
      * Get macroname
      */
     amacro->name = gerb_fgetstring(fd, '*');
-
+    c = gerb_fgetc(fd);	/* skip '*' */
+    if (c == EOF) {
+	continueLoop = 0;
+    }
+    
     /*
      * Since I'm lazy I have a dummy head. Therefore the first 
      * instruction in all programs will be NOP.
      */
     amacro->program = new_instruction();
     ip = amacro->program;
-
-    while(1) {
-	/*
-	 * First element describes which primitive element to use
-	 */
-	if (primitive == 0) {
-	    primitive = gerb_fgetint(fd, NULL);
-	}
-
-	switch (gerb_fgetc(fd)) {
+    
+    while(continueLoop) {
+	
+	c = gerb_fgetc(fd);
+	switch (c) {
 	case '$':
-	    ip->next = new_instruction(); /* XXX Check return value */
-	    ip = ip->next;
-	    ip->opcode = PPUSH;
-	    amacro->nuf_push++;
-	    ip->data.ival = gerb_fgetint(fd, NULL);
-	    comma = 0;
+	    if (found_primitive) {
+		ip->next = new_instruction(); /* XXX Check return value */
+		ip = ip->next;
+		ip->opcode = PPUSH;
+		amacro->nuf_push++;
+		ip->data.ival = gerb_fgetint(fd, NULL);
+		comma = 0;
+	    } else {
+		equate = gerb_fgetint(fd, NULL);
+	    }
 	    break;
 	case '*':
 	    if (math_op != NOP) {
@@ -122,15 +128,31 @@ parse_aperture_macro(gerb_file_t *fd)
 	     * Check is due to some gerber files has spurious empty lines.
 	     * (EagleCad of course).
 	     */
-	    if (primitive != 0) {
+	    if (found_primitive) {
 		ip->next = new_instruction(); /* XXX Check return value */
 		ip = ip->next;
-		ip->opcode = PRIM;
-		ip->data.ival = primitive;
+		if (equate) {
+		    ip->opcode = PPOP;
+		    ip->data.ival = equate;
+		} else {
+		    ip->opcode = PRIM;
+		    ip->data.ival = primitive;
+		}
+		equate = 0;
 		primitive = 0;
+		found_primitive = 0;
+	    }
+	    break;
+	case '=':
+	    if (equate) {
+		found_primitive = 1;
 	    }
 	    break;
 	case ',':
+	    if (!found_primitive) {
+		found_primitive = 1;
+		break;
+	    }
 	    if (math_op != NOP) {
 		ip->next = new_instruction(); /* XXX Check return value */
 		ip = ip->next;
@@ -146,6 +168,7 @@ parse_aperture_macro(gerb_file_t *fd)
 		ip->opcode = math_op;
 	    }
 	    math_op = ADD;
+	    comma = 1;
 	    break;
 	case '-':
 	    if (comma) {
@@ -167,7 +190,7 @@ parse_aperture_macro(gerb_file_t *fd)
 		ip->opcode = math_op;
 	    }
 	    math_op = DIV;
-	    comma = 0;
+	    comma = 1;
 	    break;
 	case 'X':
 	case 'x':
@@ -177,9 +200,19 @@ parse_aperture_macro(gerb_file_t *fd)
 		ip->opcode = math_op;
 	    }
 	    math_op = MUL;
-	    comma = 0;
+	    comma = 1;
 	    break;
 	case '0':
+	    /*
+	     * Comments in aperture macros are a definition starting with
+	     * zero and ends with a '*'
+	     */
+	    if (!found_primitive && (primitive == 0)) {
+		/* Comment continues 'til next *, just throw it away */
+		gerb_fgetstring(fd, '*');
+		c = gerb_fgetc(fd); /* Read the '*' */
+		break;
+	    }
 	case '1':
 	case '2':
 	case '3':
@@ -189,6 +222,14 @@ parse_aperture_macro(gerb_file_t *fd)
 	case '7':
 	case '8':
 	case '9':
+	    /* 
+	     * First number in an aperture macro describes the primitive
+	     * as a numerical value
+	     */
+	    if (!found_primitive) {
+		primitive = (primitive * 10) + (c - '0');
+		break;
+	    }
 	    (void)gerb_ungetc(fd);
 	    ip->next = new_instruction(); /* XXX Check return value */
 	    ip = ip->next;
@@ -208,7 +249,12 @@ parse_aperture_macro(gerb_file_t *fd)
 	    /* Whitespace */
 	    break;
 	}
+	if (c == EOF) {
+	    continueLoop = 0;
+	}
     }
+    free (amacro);
+    return NULL;
 }
 
 
@@ -255,6 +301,9 @@ print_program(amacro_t *amacro)
 	case PUSH: 
 	    printf(" PUSH %f\n", ip->data.fval);
 	    break;
+	case PPOP:
+	    printf(" PPOP %d\n", ip->data.ival);
+	    break;
 	case PPUSH:
 	    printf(" PPUSH %d\n", ip->data.ival);
 	    break;
@@ -277,5 +326,6 @@ print_program(amacro_t *amacro)
 	    printf("  ERROR!\n");
 	    break;
 	}
+	fflush(stdout);
     }
 } /* print_program */
