@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: amacro.h,v 1.2 2002/09/07 13:47:00 spetm Exp $
+ * $Id: amacro.h,v 1.3 2007/12/28 22:07:30 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,10 @@ enum opcodes {NOP,      /* No Operation */
 	      PUSH,     /* Ordinary stack operations. Uses float */
 	      PPUSH,    /* Parameter onto stack, 1 is first parameter and 
 			    so on (compare gerber $1, $2 and so on */ 
+	      PPOP,     /* Data on stack popped onto parameter register.
+			   First parameter popped from stack is which register
+			   to store data and second parameter popped is actual
+			   data. */
 	      ADD, SUB, /* Mathematical operations */
 	      MUL, DIV, 
 	      PRIM};    /* Defines what primitive to draw. Inparameters
