@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: color.c,v 1.4 2003/01/15 22:43:07 spetm Exp $
+ * $Id: color.c,v 1.6 2007/12/21 02:36:12 brorson Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
  * Allocates a color in the systems colormap.
  */
 GdkColor *
-alloc_color(int r, int g, int b, char *colorname)
+alloc_color_old(int r, int g, int b, char *colorname)
 {
     GdkColor *color;
 
@@ -43,7 +43,7 @@ alloc_color(int r, int g, int b, char *colorname)
     if (b < 0 || b > MAX_COLOR_RESOLUTION)
 	GERB_MESSAGE("Blue out range: %d\n", b);
 
-    color = (struct _GdkColor *)malloc(sizeof(struct _GdkColor));
+    color = (struct _GdkColor *)g_malloc(sizeof(struct _GdkColor));
     if (color == NULL)
 	return NULL;
 
