@@ -3,7 +3,7 @@
  * drill.h
  * Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: drill.h,v 1.10 2001/12/06 01:35:27 pitch Exp $
+ * $Id: drill.h,v 1.14 2008/01/08 00:01:12 thepurlieu Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,14 +28,16 @@ extern "C" {
 #endif
 
 #include <stdio.h>
+#include <glib.h>
 #include "gerb_image.h"
 #include "gerb_file.h"
 
-#define TOOL_MIN 0
-#define TOOL_MAX 999
+#define TOOL_MIN 1  /* T00 code is reserved for unload tool command */
+#define TOOL_MAX 9999
 
 gerb_image_t *parse_drillfile(gerb_file_t *fd);
-int drill_file_p(gerb_file_t *fd);
+gboolean
+drill_file_p(gerb_file_t *fd, gboolean *returnFoundBinary);
 
 #ifdef __cplusplus
 }
