@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: exportimage.h,v 1.1 2002/05/18 13:14:45 spetm Exp $
+ * $Id: exportimage.h,v 1.2 2007/12/17 21:58:33 thepurlieu Exp $
  *
  * Contributed by Dino Ghilardi <dino.ghilardi@ieee.org> 
  *
@@ -25,9 +25,19 @@
 
 #ifndef EXPORTIMAGE_H
 #define EXPORTIMAGE_H
+#endif
 
-#include <gtk/gtk.h>
+#ifdef EXPORT_PNG
+void exportimage_export_to_png_file_autoscaled (int widthInPixels, int heightInPixels, gchar *filename);
+void exportimage_export_to_png_file (gerbv_render_info_t *renderInfo, gchar *filename);
+#endif
 
-gboolean png_export(GdkPixmap* imagetosave, char* filename);
+void exportimage_export_to_pdf_file_autoscaled (int widthInPoints, int heightInPoints, gchar *filename);
+void exportimage_export_to_pdf_file (gerbv_render_info_t *renderInfo, gchar *filename);
+
+void exportimage_export_to_postscript_file_autoscaled (int widthInPoints, int heightInPoints, gchar *filename);
+void exportimage_export_to_postscript_file (gerbv_render_info_t *renderInfo, gchar *filename);
+
+void exportimage_export_to_svg_file_autoscaled (int widthInPoints, int heightInPoints, gchar *filename);
+void exportimage_export_to_svg_file (gerbv_render_info_t *renderInfo, gchar *filename);
 
-#endif /* EXPORTIMAGE_H */
