@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_error.h,v 1.1 2003/01/15 22:43:07 spetm Exp $
+ * $Id: gerb_error.h,v 1.5 2008/01/12 05:30:16 danmc Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,16 @@
 #define GERB_ERROR_H
 #include <glib.h>
 
+enum error_type_t {FATAL, GRB_ERROR, WARNING, NOTE};
+
+typedef struct error_list_t {
+    int layer;
+    char *error_text;
+    enum error_type_t type;
+    struct error_list_t *next;
+} error_list_t;
+
+
 #define GERB_FATAL_ERROR(t...) g_log(NULL, G_LOG_LEVEL_ERROR, ##t);
 #define GERB_COMPILE_ERROR(t...)  g_log(NULL, G_LOG_LEVEL_CRITICAL, ##t);
 #define GERB_COMPILE_WARNING(t...)  g_log(NULL, G_LOG_LEVEL_WARNING, ##t);
