@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_image.h,v 1.18.8.1 2006/07/23 21:28:11 spetm Exp $
+ * $Id: gerb_image.h,v 1.33 2008/01/24 03:23:53 thepurlieu Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,26 +24,28 @@
 #ifndef GERB_IMAGE_H
 #define GERB_IMAGE_H
 
-#include "amacro.h"
+#include "gerb_aperture.h"
+#include "gerb_transf.h"
+#include "gerb_stats.h"
+#include "drill_stats.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-	
-#define APERTURE_MIN 10
-#define APERTURE_MAX 999
-	
-enum aperture_state_t {OFF, ON, FLASH};
-enum aperture_t {CIRCLE, RECTANGLE, OVAL, POLYGON, MACRO};
-enum unit_t {INCH, MM};
+#include <glib.h> /* To pick up gpointer */
+ 
 enum polarity_t {POSITIVE, NEGATIVE, DARK, CLEAR};
-enum omit_zeros_t {LEADING, TRAILING, EXPLICIT};
+enum omit_zeros_t {LEADING, TRAILING, EXPLICIT, ZEROS_UNSPECIFIED};
 enum coordinate_t {ABSOLUTE, INCREMENTAL};
 enum interpolation_t {LINEARx1, LINEARx10, LINEARx01, LINEARx001, 
 		      CW_CIRCULAR, CCW_CIRCULAR, PAREA_START, PAREA_END};
 enum encoding_t {NONE, ASCII, EBCDIC, BCD, ISO_ASCII, EIA };
-
+enum layertype_t {GERBER, DRILL, PICK_AND_PLACE};
+enum knockout_t {NOKNOCKOUT, FIXEDKNOCK, BORDER};
+enum mirror_state_t {NOMIRROR, FLIPA, FLIPB, FLIPAB};
+enum axis_select_t {NOSELECT, SWAPAB};
+enum image_justify_type_t {NOJUSTIFY, LOWERLEFT, CENTERJUSTIFY};
 
 typedef struct gerb_cirseg {
     double cp_x;
@@ -54,6 +56,43 @@ typedef struct gerb_cirseg {
     double angle2;
 } gerb_cirseg_t;
 
+typedef struct gerb_step_and_repeat { /* SR parameters */
+    int X;
+    int Y;
+    double dist_X;
+    double dist_Y;
+} gerb_step_and_repeat_t;
+ 
+typedef struct {
+    gboolean firstInstance;
+    enum knockout_t type;
+    enum polarity_t polarity;
+    gdouble lowerLeftX;
+    gdouble lowerLeftY;
+    gdouble width;
+    gdouble height;
+    gdouble border;
+} gerb_knockout_t;
+ 
+typedef struct {
+    gerb_step_and_repeat_t stepAndRepeat;
+    gerb_knockout_t knockout;
+    gdouble rotation;
+    enum polarity_t polarity; 
+    gchar *name;
+    gpointer next;
+} gerb_layer_t;
+
+typedef struct {
+    enum axis_select_t axisSelect;
+    enum mirror_state_t mirrorState;
+    enum unit_t unit;
+    gdouble offsetA;
+    gdouble offsetB;
+    gdouble scaleA;
+    gdouble scaleB;
+    gpointer next;
+} gerb_netstate_t;
 
 typedef struct gerb_net {
     double start_x;
@@ -61,25 +100,15 @@ typedef struct gerb_net {
     double stop_x;
     double stop_y;
     int aperture;
-    enum polarity_t layer_polarity; 
     enum aperture_state_t aperture_state;
     enum interpolation_t interpolation;
-    enum unit_t unit;
-    int nuf_pcorners; /* If interpolation=PAREA_START, corners in polygon */
     struct gerb_cirseg *cirseg;
     struct gerb_net *next;
+    GString *label;
+    gerb_layer_t *layer;
+    gerb_netstate_t *state;
 } gerb_net_t;
 
-
-typedef struct gerb_aperture {
-    enum aperture_t type;
-    amacro_t *amacro;
-    double parameter[5];
-    int nuf_parameters;
-    enum unit_t unit;
-} gerb_aperture_t;
-
-
 typedef struct gerb_format {
     enum omit_zeros_t omit_zeros;
     enum coordinate_t coordinate;
@@ -101,28 +130,31 @@ typedef struct gerb_image_info {
     double min_y;
     double max_x;
     double max_y;
-    double offset_a;
-    double offset_b;
-    double offset_a_in;
-    double offset_b_in;
+    double offsetA;
+    double offsetB;
     enum encoding_t encoding;
-    double scale_factor_A;  /* SF parameters */
-    double scale_factor_B;
-    struct {                /* SR parameters */
-	int X;
-	int Y;
-	double dist_X;
-	double dist_Y;
-    } step_and_repeat;
+    double imageRotation;
+    enum image_justify_type_t imageJustifyTypeA;
+    enum image_justify_type_t imageJustifyTypeB;
+    gdouble imageJustifyOffsetA;
+    gdouble imageJustifyOffsetB;
+    gdouble imageJustifyOffsetActualA;
+    gdouble imageJustifyOffsetActualB;
+    gchar *plotterFilm;
 } gerb_image_info_t;
 
-
-typedef struct gerb_image {
+typedef struct {
+    enum layertype_t layertype;
     gerb_aperture_t *aperture[APERTURE_MAX];
+    gerb_layer_t *layers;
+    gerb_netstate_t *states;
     amacro_t *amacro;
     gerb_format_t *format;
     gerb_image_info_t *info;
     gerb_net_t *netlist;
+    gerb_transf_t *transf;
+    gerb_stats_t *gerb_stats;
+    drill_stats_t *drill_stats;
 } gerb_image_t;
 
 
@@ -155,6 +187,12 @@ gerb_verify_error_t gerb_image_verify(gerb_image_t *image);
 /* Dumps a written version of image to stdout */
 void gerb_image_dump(gerb_image_t *image);
 
+gerb_layer_t *
+gerb_image_return_new_layer (gerb_layer_t *previousLayer);
+
+gerb_netstate_t *
+gerb_image_return_new_netstate (gerb_netstate_t *previousState);
+
 #ifdef __cplusplus
 }
 #endif
