@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerber.h,v 1.17 2002/10/18 21:04:53 spetm Exp $
+ * $Id: gerber.h,v 1.23 2008/01/08 00:01:13 thepurlieu Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,16 @@ extern "C" {
 #endif
 
 #include <stdio.h>
+#include <glib.h>
 #include "gerb_image.h"
 #include "gerb_file.h"
 
 /*
  * parse gerber file pointed to by fd
  */
-gerb_image_t *parse_gerb(gerb_file_t *fd);
-
+gerb_image_t *parse_gerb(gerb_file_t *fd, gchar *directoryPath);
+gboolean gerber_is_rs274x_p(gerb_file_t *fd, gboolean *returnFoundBinary);
+gboolean gerber_is_rs274d_p(gerb_file_t *fd);
 
 #ifdef __cplusplus
 }
