@@ -2,9 +2,9 @@
  * gEDA - GNU Electronic Design Automation
  * This file is a part of gerbv.
  *
- *   Copyright (C) 2000-2006 Stefan Petersen (spe@stacken.kth.se)
+ *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: project.c,v 1.2.6.1 2006/07/25 17:16:19 spetm Exp $
+ * $Id: project.c,v 1.16 2008/01/13 22:26:28 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+/*! @file project.c
+    @brief routines for loading and saving project files */ 
+
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -55,6 +59,9 @@
 #include "project.h"
 #include "scheme-private.h"
 
+/* DEBUG printing.  #define DEBUG 1 in config.h to use this fcn. */
+#define dprintf if(DEBUG) printf
+
 static project_list_t *plist_top = NULL;
 
 static void
@@ -96,13 +103,41 @@ get_value_string(scheme *sc, pointer value)
 } /* get_value_string */
 
 
+/** Conversion of '\' into '/' and vice versa for compatibility under WIN32 
+    platforms. */
+static char *
+convert_path_separators(char* path, int conv_flag)
+{
+#if defined (__MINGW32__)        
+    char     *hit_in_path;
+
+    switch (conv_flag) {
+	
+    case MINGW_UNIX:
+        while ((hit_in_path = strchr(path, '\\'))) {
+            *hit_in_path = '/';
+        }
+        break;
+    case UNIX_MINGW:
+	while ((hit_in_path = strchr(path, '/'))) {
+            *hit_in_path = '\\';
+        }
+        break;
+    }    
+#endif
+
+    return path;
+}/* convert_path_separators */
+
+
 static pointer
 define_layer(scheme *sc, pointer args)
 {
     pointer car_el, cdr_el, name, value;
     int layerno;
     project_list_t *plist_tmp = NULL;
-    char *tmp_string;
+
+    dprintf("--> entering project.c:define_layer\n");
 
     if (!sc->vptr->is_pair(args)){
 	GERB_MESSAGE("define-layer!: Too few arguments\n");
@@ -118,34 +153,46 @@ define_layer(scheme *sc, pointer args)
     }
 
     layerno = sc->vptr->ivalue(car_el);
-
+    dprintf("    layerno = %d\n", layerno);
+    if (screen.last_loaded <= layerno) {
+	screen.last_loaded = layerno;
+    }
+    
     car_el = sc->vptr->pair_car(cdr_el);
     cdr_el = sc->vptr->pair_cdr(cdr_el);
-
-    plist_tmp = (project_list_t *)malloc(sizeof(project_list_t));
+    
+    plist_tmp = (project_list_t *)g_malloc(sizeof(project_list_t));
     memset(plist_tmp, 0, sizeof(project_list_t));
     plist_tmp->next = plist_top;
     plist_top = plist_tmp;
     plist_top->layerno = layerno;
-
+    
     while (sc->vptr->is_pair(car_el)) {
-
+	
 	name = sc->vptr->pair_car(car_el);
 	value =  sc->vptr->pair_cdr(car_el);
-
+	
 	if (!sc->vptr->is_symbol(name)) {
 	    GERB_MESSAGE("define-layer!:non-symbol found, ignoring\n");
 	    goto end_name_value_parse;
 	}
-
+	
 	if (strcmp(sc->vptr->symname(name), "color") == 0) {
 	    get_color(sc, value, plist_top->rgb);
 	} else if (strcmp(sc->vptr->symname(name), "filename") == 0) {
-	    tmp_string = get_value_string(sc, value);
-	    plist_top->filename = (char *)malloc(strlen(tmp_string) + 1);
-	    strncpy(plist_top->filename, tmp_string, strlen(tmp_string) + 1);
+	    
+            plist_top->filename = strdup(get_value_string(sc, value));
+	    plist_top->filename = convert_path_separators(plist_top->filename, 
+							  UNIX_MINGW);
+            plist_top->is_pnp = 0;
+	} else if (strcmp(sc->vptr->symname(name), "pick_and_place") == 0) {
+
+	    plist_top->filename = strdup(get_value_string(sc, value));
+	    plist_top->filename = convert_path_separators(plist_top->filename, 
+							  UNIX_MINGW);
+	    plist_top->is_pnp = 1;
 	} else if (strcmp(sc->vptr->symname(name), "inverted") == 0) {
-	    if (value ==  sc->F) {
+	    if (value == sc->F) {
 		plist_top->inverted = 0;
 	    } else if (value == sc->T) {
 		plist_top->inverted = 1;
@@ -153,8 +200,7 @@ define_layer(scheme *sc, pointer args)
 		GERB_MESSAGE("Argument to inverted must be #t or #f\n");
 	    }
 	}
-
-
+	
     end_name_value_parse:
 	car_el = sc->vptr->pair_car(cdr_el);
 	cdr_el = sc->vptr->pair_cdr(cdr_el);
@@ -164,16 +210,15 @@ define_layer(scheme *sc, pointer args)
 } /* define_layer */
 
 
-/*
- * What should be in a project?
- * Global:
- * * Background color
- * * Global path.
- * Per layer:
- * * layer color
- * * layer filename
- */
-
+/** Reads the content of a project file.
+  *  Global:\n
+  *    Background color,\n
+  *    global path,\n
+  *    corresponding pick and place file: labelled 'picknplace'\n
+  *   Per layer:\n
+  *    layer color,\n
+  *    layer filename
+  */
 project_list_t *
 read_project_file(char *filename)
 {
@@ -250,21 +295,25 @@ write_project_file(char *filename, project_list_t *project)
     project_list_t *p = project, *tmp;
 
     if ((fd = fopen(filename, "w")) == NULL) {
-	GERB_MESSAGE("Couldn't save project %s\n", filename);
-	return(-1);
+	    GERB_MESSAGE("Couldn't save project %s\n", filename);
+	    return(-1);
     }
-
     while (p) {
 	fprintf(fd, "(define-layer! %d ", p->layerno);
-	fprintf(fd, "(cons 'filename \"%s\")", p->filename);
+	
+#if defined (__MINGW32__)
+	fprintf(fd, "(cons 'filename \"%s\")", convert_path_separators(p->filename, MINGW_UNIX));    
+#else
+	fprintf(fd, "(cons 'filename \"%s\")", p->filename);    
+#endif
+    
 	if (p->inverted)
 	    fprintf(fd, "(cons 'inverted #t)");
-	fprintf(fd, "(cons 'color #(%d %d %d)))", p->rgb[0], p->rgb[1],
-		p->rgb[2]);
+	fprintf(fd, "(cons 'color #(%d %d %d)))", p->rgb[0], p->rgb[1],	p->rgb[2]);
 	fprintf(fd, "\n");
 	tmp = p;
 	p = p->next;
-	free(tmp);
+	g_free(tmp);
 	tmp = NULL;
     }
 
