@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: setup.c,v 1.1.10.1 2006/07/25 21:47:59 spetm Exp $
+ * $Id: setup.c,v 1.3 2007/12/21 02:36:13 brorson Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+#include <glib.h>
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
@@ -42,16 +43,16 @@ setup_init(void)
 
     memset((void *)&setup, 0, sizeof(setup_t));
 
-    fontstring = (char *)malloc(strlen(DEF_DISTFONTNAME) + 1);
+    fontstring = (char *)g_malloc(strlen(DEF_DISTFONTNAME) + 1);
     if (fontstring == NULL)
-        return;
+	return;
     memset((void *)fontstring, 0, strlen(DEF_DISTFONTNAME) + 1);
     strncpy(fontstring, DEF_DISTFONTNAME, strlen(DEF_DISTFONTNAME));
     setup.dist_fontname = fontstring;
 
-    fontstring = (char *)malloc(strlen(DEF_STATUSFONTNAME) + 1);
+    fontstring = (char *)g_malloc(strlen(DEF_STATUSFONTNAME) + 1);
     if (fontstring == NULL)
-        return;
+	return;
     memset((void *)fontstring, 0, strlen(DEF_STATUSFONTNAME) + 1);
     strncpy(fontstring, DEF_STATUSFONTNAME, strlen(DEF_STATUSFONTNAME));
     setup.status_fontname = fontstring;
@@ -63,7 +64,7 @@ void
 setup_destroy(void)
 {
     if (setup.dist_fontname)
-	free(setup.dist_fontname);
+	g_free(setup.dist_fontname);
     if (setup.status_fontname)
-	free(setup.status_fontname);
+	g_free(setup.status_fontname);
 }
