@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: setup.h,v 1.2.8.1 2006/07/28 10:33:13 spetm Exp $
+ * $Id: setup.h,v 1.4 2005/01/06 17:37:35 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,11 +28,13 @@
 #include "config.h"
 #endif
 
-//#define DEF_DISTFONTNAME "Helvetica Extra-Condensed 11"
 #define DEF_DISTFONTNAME "-*-helvetica-bold-r-normal--*-120-*-*-*-*-iso8859-1"
-#define DEF_STATUSFONTNAME "Courier Extra-Condensed 11"
-//#define DEF_STATUSFONTNAME "-*-fixed-*-*-normal--*-100-*-*-*-*-iso8859-1"
 
+#if defined (__MINGW32__)
+#define DEF_STATUSFONTNAME "Sans"
+#else
+#define  DEF_STATUSFONTNAME "Courier Extra-Condensed 11"
+#endif
 
 typedef struct {
     char *status_fontname;
